@@ -34,10 +34,15 @@ pub mod query_as;
 pub mod query_scalar;
 pub mod executor;
 pub mod describe;
+pub mod net;
+pub use ahash::AHashMap as HashMap;
 
 pub use error::*;
-
-pub mod net;
-
-
-pub use ahash::AHashMap as HashMap;
\ No newline at end of file
+pub use query::*;
+pub use query_as::*;
+pub use query_scalar::*;
+pub use decode::*;
+pub use encode::*;
+pub use column::*;
+pub use row::*;
+pub use executor::*;
\ No newline at end of file
